Stan Math Library: stan/math/prim/scal/err/check_consistent_sizes.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
check_consistent_sizes.hpp File Reference
`#include <stan/math/prim/scal/err/check_consistent_size.hpp>`
`#include <algorithm>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T1 , typename T2 >
bool | stan::math::check_consistent_sizes (const char *function, const char *name1, const T1 &x1, const char *name2, const T2 &x2)
| Return `true` if the dimension of x1 is consistent with x2. More...
template<typename T1 , typename T2 , typename T3 >
bool | stan::math::check_consistent_sizes (const char *function, const char *name1, const T1 &x1, const char *name2, const T2 &x2, const char *name3, const T3 &x3)
| Return `true` if the dimension of x1, x2, and x3 are consistent. More...
template<typename T1 , typename T2 , typename T3 , typename T4 >
bool | stan::math::check_consistent_sizes (const char *function, const char *name1, const T1 &x1, const char *name2, const T2 &x2, const char *name3, const T3 &x3, const char *name4, const T4 &x4)
| Return `true` if the dimension of x1, x2, x3, and x4 are consistent. More...
template<typename T1 , typename T2 , typename T3 , typename T4 , typename T5 >
bool | stan::math::check_consistent_sizes (const char *function, const char *name1, const T1 &x1, const char *name2, const T2 &x2, const char *name3, const T3 &x3, const char *name4, const T4 &x4, const char *name5, const T5 &x5)

[ Stan Home Page ] © 2011–2016, Stan Development Team.